.. _airs:

AIRS Module
============

Get Data directly from AIRS aboard NASA's Aqua Satellite.

.. py:module:: pyearthdata.airs

.. autofunction:: rel_humidity
.. autofunction:: co
.. autofunction:: dust
.. autofunction:: out_long_rad
.. autofunction:: precipitation
.. autofunction:: so2
.. autofunction:: temp
.. autofunction:: h2o_vapour
.. autofunction:: map_underlay
